==> ghost-6.6.1.zip: Ghost-6.6.1/apps/shade/src/components/ui/hover-card.tsx <==
import * as React from 'react';
import * as HoverCardPrimitive from '@radix-ui/react-hover-card';
import {SHADE_APP_NAMESPACES} from '@/ShadeApp';

import {cn} from '@/lib/utils';

const HoverCard = HoverCardPrimitive.Root;

const HoverCardTrigger = HoverCardPrimitive.Trigger;

const HoverCardContent = React.forwardRef<
  React.ElementRef<typeof HoverCardPrimitive.Content>,
  React.ComponentPropsWithoutRef<typeof HoverCardPrimitive.Content>
>(({className, align = 'center', sideOffset = 4, ...props}, ref) => (
    <HoverCardPrimitive.Portal>
        <div className={SHADE_APP_NAMESPACES}>
            <HoverCardPrimitive.Content
                ref={ref}
                align={align}
                className={cn(
                    'z-50 w-64 rounded-md border bg-popover p-4 text-popover-foreground shadow-md outline-none data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 origin-[--radix-hover-card-content-transform-origin]',
                    className
                )}
                sideOffset={sideOffset}
                {...props}
            />
        </div>
    </HoverCardPrimitive.Portal>
));
HoverCardContent.displayName = HoverCardPrimitive.Content.displayName;

export {HoverCard, HoverCardTrigger, HoverCardContent};

==> ghost-6.9.1.zip: Ghost-6.9.1/apps/shade/src/components/ui/hover-card.tsx <==
import * as React from 'react';
import * as HoverCardPrimitive from '@radix-ui/react-hover-card';
import {SHADE_APP_NAMESPACES} from '@/ShadeApp';

import {cn} from '@/lib/utils';

const HoverCard = HoverCardPrimitive.Root;

const HoverCardTrigger = HoverCardPrimitive.Trigger;

const HoverCardContent = React.forwardRef<
  React.ElementRef<typeof HoverCardPrimitive.Content>,
  React.ComponentPropsWithoutRef<typeof HoverCardPrimitive.Content>
>(({className, align = 'center', sideOffset = 4, ...props}, ref) => (
    <HoverCardPrimitive.Portal>
        <div className={SHADE_APP_NAMESPACES}>
            <HoverCardPrimitive.Content
                ref={ref}
                align={align}
                className={cn(
                    'pointer-events-auto z-50 w-64 rounded-md border bg-popover p-4 text-popover-foreground shadow-md outline-none data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 origin-[--radix-hover-card-content-transform-origin]',
                    className
                )}
                sideOffset={sideOffset}
                {...props}
            />
        </div>
    </HoverCardPrimitive.Portal>
));
HoverCardContent.displayName = HoverCardPrimitive.Content.displayName;

export {HoverCard, HoverCardTrigger, HoverCardContent};
